@@ -382,7 +382,7 @@ class Web(TestObjectBase):
         self.throwIfDisposed()
         return SaveRegionCommand(self).execute(filename)
     
-    def snapShot(self, filename, imageFormat, quality):
+    def snapShot(self, filename, imageFormat, quality  = None):
         self.throwIfDisposed()
         return SnapShotCommand(self).execute(filename, imageFormat, quality)
 
